@@ -133,6 +133,7 @@ namespace
 const KCrash::CoreConfig s_coreConfig;
 
 std::unique_ptr<char[]> s_glRenderer; // the GL_RENDERER
+std::unique_ptr<char[]> s_qtVersion;
 
 QString glRenderer()
 {
@@ -228,11 +229,13 @@ void KCrash::initialize()
         // Don't qDebug here, it loads qtlogging.ini very early which prevents unittests from doing QStandardPaths::setTestModeEnabled(true) in initTestCase()
     }
 
+    s_qtVersion.reset(qstrdup(qVersion()));
+
     if (QCoreApplication::instance()) {
         const QString path = QCoreApplication::applicationFilePath();
         s_appFilePath.reset(qstrdup(qPrintable(path))); // This intentionally cannot be changed by the application!
         KCrash::setApplicationFilePath(path);
-        if (auto guiApp = qobject_cast<QGuiApplication *>(QCoreApplication::instance())) {
+        if (qobject_cast<QGuiApplication *>(QCoreApplication::instance())) {
             s_glRenderer.reset(qstrdup(glRenderer().toUtf8().constData()));
         }
     } else {
@@ -514,6 +517,12 @@ void KCrash::defaultCrashHandler(int sig)
             data.add("--glrenderer", s_glRenderer.get());
         }
 
+        if (s_qtVersion) {
+            data.add("--qtversion", s_qtVersion.get());
+        }
+
+        data.add("--kdeframeworksversion", KCRASH_VERSION_STRING);
+
         const QByteArray platformName = QGuiApplication::platformName().toUtf8();
         if (!platformName.isEmpty()) {
             if (strcmp(platformName.constData(), "wayland-org.kde.kwin.qpa") == 0) { // redirect kwin's internal QPA to wayland proper
